rsbac-backup
------------

RSBAC attributes backup.

usage::
 
  rsbac-backup [-h] [-v] [-t] [-m module [module ...]] [-d backup directory] [-r]

-h      show this help message and exit
-v      Make the script verbose.
-t      Print time to execute.
-m      Set an individual module
-d      Set backup directory for storing backup. Default is CurrentWorkDirectory/backup/.
